@@ -64,11 +64,11 @@ GpmCell		*gpm_cell_new				(void);
 GpmCellUnit	*gpm_cell_get_unit			(GpmCell	*cell);
 gboolean	 gpm_cell_set_type			(GpmCell	*cell,
 							 GpmCellUnitKind kind);
-gboolean	 gpm_cell_set_hal_udi			(GpmCell	*cell,
+gboolean	 gpm_cell_set_device_id			(GpmCell	*cell,
 							 const gchar	*udi);
 gboolean	 gpm_cell_set_phone_index		(GpmCell	*cell,
 							 guint		 index);
-const gchar	*gpm_cell_get_udi			(GpmCell	*cell);
+const gchar	*gpm_cell_get_device_id			(GpmCell	*cell);
 gchar		*gpm_cell_get_icon			(GpmCell	*cell);
 gchar		*gpm_cell_get_id			(GpmCell	*cell);
 gboolean	 gpm_cell_print				(GpmCell	*cell);
