@@ -44,12 +44,16 @@
 
 #include <libhal-gpower.h>
 
+#ifdef HAVE_POLKIT
+#include <polkit/polkit.h>
+#include <polkit-dbus/polkit-dbus.h>
+#endif
+
 #include "gpm-conf.h"
 #include "gpm-screensaver.h"
 #include "gpm-common.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-control.h"
-#include "gpm-polkit.h"
 #include "gpm-networkmanager.h"
 
 #define GPM_CONTROL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_CONTROL, GpmControlPrivate))
@@ -58,9 +62,6 @@ struct GpmControlPrivate
 {
 	GpmConf			*conf;
 	HalGPower		*hal_power;
-	GpmPolkit		*polkit;
-	time_t			 last_resume_event;
-	guint			 suppress_policy_timeout;
 };
 
 enum {
@@ -91,7 +92,30 @@ gpm_control_error_quark (void)
 }
 
 /**
- * gpm_control_is_policy_timout_valid:
+ * gpm_control_is_user_privileged:
+ * @polkit: This polkit class instance
+ * Return value: Success value.
+ **/
+gboolean
+gpm_control_is_user_privileged (GpmControl *control, const gchar *privilege)
+{
+	gboolean ret = TRUE;
+#ifdef HAVE_POLKIT
+	polkit_uint64_t mask;
+	pid_t pid;
+
+	pid = getpid ();
+	mask = polkit_check_auth (pid, privilege, NULL);
+	if (mask == 0) {
+		egg_warning ("failed to authorise for privilege %s", privilege);
+		ret = FALSE;
+	}
+#endif
+	return ret;
+}
+
+/**
+ * gpm_control_check_foreground_console:
  * @manager: This class instance
  * @action: The action we want to do, e.g. "suspend"
  *
@@ -103,48 +127,27 @@ gpm_control_error_quark (void)
  *
  * Return value: TRUE if we can perform the action.
  **/
-gboolean
-gpm_control_is_policy_timout_valid (GpmControl *control)
+static gboolean
+gpm_control_check_foreground_console (GpmControl *control)
 {
 #ifdef HAVE_CHECK_FG
 	gchar *argv[] = { "check-foreground-console", NULL };
 	int retcode;
-#endif
 
-	if ((time (NULL) - control->priv->last_resume_event) <=
-	    control->priv->suppress_policy_timeout) {
-		gpm_debug ("Skipping suppressed action");
-		return FALSE;
-	}
-
-#ifdef HAVE_CHECK_FG
 	if (!g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL,
-				 NULL, NULL, &retcode, NULL)  || ! WIFEXITED (retcode) ) {
+				 NULL, NULL, &retcode, NULL)  || ! WIFEXITED (retcode)) {
 		/* if check-foreground-console could not be executed,
 		 * assume active console */
-		gpm_debug ("could not execute check-foreground-console");
+		egg_debug ("could not execute check-foreground-console");
 		return TRUE;
 	}
-	gpm_debug ("check-foreground-console returned with %i", WEXITSTATUS (retcode));
+	egg_debug ("check-foreground-console returned with %i", WEXITSTATUS (retcode));
 	return WEXITSTATUS (retcode) == 0;
 #endif
 	/* no other checks failed, so return okay */
 	return TRUE;
 }
 
-/**
- * gpm_control_reset_event_time:
- * @manager: This class instance
- *
- * Resets the time so we do not do any more actions until the
- * timeout has passed.
- **/
-void
-gpm_control_reset_event_time (GpmControl *control)
-{
-	control->priv->last_resume_event = time (NULL);
-}
-
 /**
  * gpm_control_allowed_suspend:
  * @control: This class instance
@@ -161,15 +164,15 @@ gpm_control_allowed_suspend (GpmControl *control,
 	gboolean conf_ok;
 	gboolean polkit_ok = TRUE;
 	gboolean hal_ok = FALSE;
+	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
 	*can = FALSE;
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, &conf_ok);
 	hal_ok = hal_gpower_can_suspend (control->priv->hal_power);
-	if (control->priv->polkit) {
-		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-suspend");
-	}
-	if ( conf_ok && hal_ok && polkit_ok ) {
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.suspend");
+	fg = gpm_control_check_foreground_console (control);
+	if (conf_ok && hal_ok && polkit_ok && fg) {
 		*can = TRUE;
 	}
 
@@ -192,15 +195,15 @@ gpm_control_allowed_hibernate (GpmControl *control,
 	gboolean conf_ok;
 	gboolean polkit_ok = TRUE;
 	gboolean hal_ok = FALSE;
+	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
 	*can = FALSE;
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, &conf_ok);
 	hal_ok = hal_gpower_can_hibernate (control->priv->hal_power);
-	if (control->priv->polkit) {
-		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-hibernate");
-	}
-	if ( conf_ok && hal_ok && polkit_ok ) {
+	fg = gpm_control_check_foreground_console (control);
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.hibernate");
+	if (conf_ok && hal_ok && polkit_ok && fg) {
 		*can = TRUE;
 	}
 	return TRUE;
@@ -218,12 +221,12 @@ gpm_control_allowed_shutdown (GpmControl *control,
 			      GError    **error)
 {
 	gboolean polkit_ok = TRUE;
+	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 	*can = FALSE;
-	if (control->priv->polkit) {
-		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-shutdown");
-	}
-	if (polkit_ok == TRUE) {
+	fg = gpm_control_check_foreground_console (control);
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.shutdown");
+	if (polkit_ok && fg) {
 		*can = TRUE;
 	}
 	return TRUE;
@@ -242,12 +245,12 @@ gpm_control_allowed_reboot (GpmControl *control,
 			    GError    **error)
 {
 	gboolean polkit_ok = TRUE;
+	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 	*can = FALSE;
-	if (control->priv->polkit) {
-		polkit_ok = gpm_polkit_is_user_privileged (control->priv->polkit, "hal-power-reboot");
-	}
-	if (polkit_ok == TRUE) {
+	fg = gpm_control_check_foreground_console (control);
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.reboot");
+	if (polkit_ok && fg) {
 		*can = TRUE;
 	}
 	return TRUE;
@@ -300,7 +303,7 @@ gpm_control_shutdown (GpmControl *control,
 
 	gpm_control_allowed_shutdown (control, &allowed, error);
 	if (allowed == FALSE) {
-		gpm_warning ("Cannot shutdown");
+		egg_warning ("Cannot shutdown");
 		g_set_error (error,
 			     GPM_CONTROL_ERROR,
 			     GPM_CONTROL_ERROR_GENERAL,
@@ -311,14 +314,14 @@ gpm_control_shutdown (GpmControl *control,
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_SESSION_REQUEST_SAVE, &save_session);
 	/* We can set g-p-m to not save the session to avoid confusing new
 	   users. By default we save the session to preserve data. */
-	if (save_session == TRUE) {
+	if (save_session) {
 		gnome_client_request_save (gnome_master_client (),
 					   GNOME_SAVE_GLOBAL,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 	}
 
 	ret = hal_gpower_shutdown (control->priv->hal_power, error);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_control_convert_hal_error (control, error);
 	}
 
@@ -340,7 +343,7 @@ gpm_control_reboot (GpmControl *control,
 
 	gpm_control_allowed_reboot (control, &allowed, error);
 	if (allowed == FALSE) {
-		gpm_warning ("Cannot reboot");
+		egg_warning ("Cannot reboot");
 		g_set_error (error,
 			     GPM_CONTROL_ERROR,
 			     GPM_CONTROL_ERROR_GENERAL,
@@ -351,7 +354,7 @@ gpm_control_reboot (GpmControl *control,
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_SESSION_REQUEST_SAVE, &save_session);
 	/* We can set g-p-m to not save the session to avoid confusing new
 	   users. By default we save the session to preserve data. */
-	if (save_session == TRUE) {
+	if (save_session) {
 		gnome_client_request_save (gnome_master_client (),
 					   GNOME_SAVE_GLOBAL,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
@@ -383,10 +386,10 @@ gpm_control_get_lock_policy (GpmControl  *control,
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_USE_SCREENSAVER, &use_ss_setting);
 	if (use_ss_setting) {
 		gpm_conf_get_bool (control->priv->conf, GS_PREF_LOCK_ENABLED, &do_lock);
-		gpm_debug ("Using ScreenSaver settings (%i)", do_lock);
+		egg_debug ("Using ScreenSaver settings (%i)", do_lock);
 	} else {
 		gpm_conf_get_bool (control->priv->conf, policy, &do_lock);
-		gpm_debug ("Using custom locking settings (%i)", do_lock);
+		egg_debug ("Using custom locking settings (%i)", do_lock);
 	}
 	return do_lock;
 }
@@ -407,7 +410,7 @@ gpm_control_suspend (GpmControl *control,
 
 	gpm_control_allowed_suspend (control, &allowed, error);
 	if (allowed == FALSE) {
-		gpm_syslog ("cannot suspend as not allowed from policy");
+		egg_debug ("cannot suspend as not allowed from policy");
 		g_set_error (error,
 			     GPM_CONTROL_ERROR,
 			     GPM_CONTROL_ERROR_GENERAL,
@@ -418,51 +421,49 @@ gpm_control_suspend (GpmControl *control,
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_SUSPEND, &lock_gnome_keyring);
-	if (lock_gnome_keyring == TRUE) {
+	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
-			gpm_warning ("could not lock keyring");
+			egg_warning ("could not lock keyring");
 		}
 	}
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_SUSPEND);
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		gpm_screensaver_lock (screensaver);
 	}
 
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep == TRUE) {
+	if (nm_sleep) {
 		gpm_networkmanager_sleep ();
 	}
 
 	/* Do the suspend */
-	gpm_debug ("emitting sleep");
+	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
 	ret = hal_gpower_suspend (control->priv->hal_power, 0, error);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_control_convert_hal_error (control, error);
 	}
 
-	gpm_debug ("emitting resume");
+	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
 
-	if (ret == FALSE) {
-		gpm_debug ("emitting sleep-failure");
+	if (!ret) {
+		egg_debug ("emitting sleep-failure");
 		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_SUSPEND);
 	}
 
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		gpm_screensaver_poke (screensaver);
 	}
 
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep == TRUE) {
+	if (nm_sleep) {
 		gpm_networkmanager_wake ();
 	}
 
-	/* save the time that we resumed */
-	gpm_control_reset_event_time (control);
 	g_object_unref (screensaver);
 
 	return ret;
@@ -485,7 +486,7 @@ gpm_control_hibernate (GpmControl *control,
 	gpm_control_allowed_hibernate (control, &allowed, error);
 
 	if (allowed == FALSE) {
-		gpm_syslog ("cannot hibernate as not allowed from policy");
+		egg_debug ("cannot hibernate as not allowed from policy");
 		g_set_error (error,
 			     GPM_CONTROL_ERROR,
 			     GPM_CONTROL_ERROR_GENERAL,
@@ -496,71 +497,53 @@ gpm_control_hibernate (GpmControl *control,
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_HIBERNATE, &lock_gnome_keyring);
-	if (lock_gnome_keyring == TRUE) {
+	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
-			gpm_warning ("could not lock keyring");
+			egg_warning ("could not lock keyring");
 		}
 	}
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_HIBERNATE);
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		gpm_screensaver_lock (screensaver);
 	}
 
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep == TRUE) {
+	if (nm_sleep) {
 		gpm_networkmanager_sleep ();
 	}
 
-	gpm_debug ("emitting sleep");
+	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
 	ret = hal_gpower_hibernate (control->priv->hal_power, error);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_control_convert_hal_error (control, error);
 	}
 
-	gpm_debug ("emitting resume");
+	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
-	if (ret == FALSE) {
-		gpm_debug ("emitting sleep-failure");
+	if (!ret) {
+		egg_debug ("emitting sleep-failure");
 		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_HIBERNATE);
 	}
 
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		gpm_screensaver_poke (screensaver);
 	}
 
 	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep == TRUE) {
+	if (nm_sleep) {
 		gpm_networkmanager_wake ();
 	}
 
-	/* save the time that we resumed */
-	gpm_control_reset_event_time (control);
 	g_object_unref (screensaver);
 
 	return ret;
 }
 
-/**
- * gpm_control_constructor:
- **/
-static GObject *
-gpm_control_constructor (GType		  type,
-			 guint		  n_construct_properties,
-			 GObjectConstructParam *construct_properties)
-{
-	GpmControl      *control;
-	GpmControlClass *klass;
-	klass = GPM_CONTROL_CLASS (g_type_class_peek (GPM_TYPE_CONTROL));
-	control = GPM_CONTROL (G_OBJECT_CLASS (gpm_control_parent_class)->constructor
-			      		     (type, n_construct_properties, construct_properties));
-	return G_OBJECT (control);
-}
-
 /**
  * gpm_control_finalize:
  **/
@@ -575,9 +558,6 @@ gpm_control_finalize (GObject *object)
 
 	g_object_unref (control->priv->conf);
 	g_object_unref (control->priv->hal_power);
-	if (control->priv->polkit) {
-		g_object_unref (control->priv->polkit);
-	}
 
 	g_return_if_fail (control->priv != NULL);
 	G_OBJECT_CLASS (gpm_control_parent_class)->finalize (object);
@@ -590,8 +570,7 @@ static void
 gpm_control_class_init (GpmControlClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	object_class->finalize	   = gpm_control_finalize;
-	object_class->constructor  = gpm_control_constructor;
+	object_class->finalize = gpm_control_finalize;
 
 	signals [RESUME] =
 		g_signal_new ("resume",
@@ -636,28 +615,14 @@ gpm_control_class_init (GpmControlClass *klass)
 /**
  * gpm_control_init:
  * @control: This control class instance
- *
- * initialises the control class. NOTE: We expect control objects
- * to *NOT* be removed or added during the session.
- * We only control the first control object if there are more than one.
  **/
 static void
 gpm_control_init (GpmControl *control)
 {
 	control->priv = GPM_CONTROL_GET_PRIVATE (control);
 
-	/* this will be NULL if we don't compile in support */
-	control->priv->polkit = gpm_polkit_new ();
 	control->priv->hal_power = hal_gpower_new ();
-
 	control->priv->conf = gpm_conf_new ();
-	gpm_conf_get_uint (control->priv->conf, GPM_CONF_POLICY_TIMEOUT,
-			   &control->priv->suppress_policy_timeout);
-	gpm_debug ("Using a supressed policy timeout of %i seconds",
-		   control->priv->suppress_policy_timeout);
-
-	/* Pretend we just resumed when we start to let actions settle */
-	gpm_control_reset_event_time (control);
 }
 
 /**
