@@ -42,7 +42,7 @@
 #include "gpm-ac-adapter.h"
 #include "gpm-common.h"
 #include "gpm-conf.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-notify.h"
 #include "gpm-stock-icons.h"
 
@@ -70,7 +70,7 @@ enum {
 	LAST_SIGNAL
 };
 
-//static guint signals [LAST_SIGNAL] = { 0, };
+//static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_notify_object = NULL;
 
 G_DEFINE_TYPE (GpmNotify, gpm_notify, G_TYPE_OBJECT)
@@ -86,7 +86,7 @@ notify_closed_cb (NotifyNotification *libnotify,
 		  GpmNotify	     *notify)
 {
 	/* just invalidate the pointer */
-	gpm_debug ("caught notification closed signal");
+	egg_debug ("caught notification closed signal");
 //	notify->priv->libnotify = NULL;
 }
 
@@ -104,7 +104,7 @@ gpm_notify_create (GpmNotify 	 *notify,
 	}
 
 	if (notify->priv->status_icon != NULL &&
-	    gtk_status_icon_get_visible (notify->priv->status_icon) == TRUE) {
+	    gtk_status_icon_get_visible (notify->priv->status_icon)) {
 		notify->priv->libnotify = notify_notification_new_with_status_icon (title, content,
 										    msgicon,
 										    notify->priv->status_icon);
@@ -121,9 +121,9 @@ gpm_notify_create (GpmNotify 	 *notify,
 	}
 
 	if (urgency == GPM_NOTIFY_URGENCY_CRITICAL) {
-		gpm_warning ("libnotify: %s : %s", GPM_NAME, content);
+		egg_warning ("libnotify: %s : %s", GPM_NAME, content);
 	} else {
-		gpm_debug ("libnotify: %s : %s", GPM_NAME, content);
+		egg_debug ("libnotify: %s : %s", GPM_NAME, content);
 	}
 
 	g_signal_connect (notify->priv->libnotify, "closed", G_CALLBACK (notify_closed_cb), notify);
@@ -135,8 +135,8 @@ gpm_notify_show (GpmNotify *notify)
 {
 	gboolean ret;
 	ret = notify_notification_show (notify->priv->libnotify, NULL);
-	if (ret == FALSE) {
-		gpm_warning ("failed to send notification");
+	if (!ret) {
+		egg_warning ("failed to send notification");
 	}
 	return ret;
 }
@@ -232,7 +232,7 @@ gpm_notify_display (GpmNotify 	 *notify,
 						     "<span size='larger'><b>%s</b></span>",
 						     GPM_NAME);
 
-	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), content);
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), "%s", content);
 
 	g_signal_connect_swapped (dialog,
 				  "response",
@@ -280,8 +280,8 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 {
 	/* for where we add back the ac_adapter before the "AC Power unplugged"
 	 * message times out. */
-	if (on_ac == TRUE) {
-		gpm_debug ("clearing notify due ac being present");
+	if (on_ac) {
+		egg_debug ("clearing notify due ac being present");
 		gpm_notify_cancel (notify);
 	}
 }
@@ -311,20 +311,20 @@ notify_general_clicked_cb (NotifyNotification *libnotify,
 	gscreen = gdk_screen_get_default();
 
 	if (strcmp (action, "dont-show-again") == 0) {
-		gpm_debug ("not showing warning anymore for %s!", notify->priv->do_not_show_gconf);
+		egg_debug ("not showing warning anymore for %s!", notify->priv->do_not_show_gconf);
 		gpm_conf_set_bool (notify->priv->conf, notify->priv->do_not_show_gconf, FALSE);
 		notify->priv->do_not_show_gconf = NULL;
 		return;
 	}
 	if (strcmp (action, "visit-website") == 0) {
-		gpm_debug ("autovisit website %s", notify->priv->internet_url);
+		egg_debug ("autovisit website %s", notify->priv->internet_url);
 		error = NULL;
 
  		cmdline = g_strconcat ("gnome-open ", notify->priv->internet_url, NULL);
 		ret = gdk_spawn_command_line_on_screen (gscreen, cmdline, &error);
 		g_free (cmdline);
 
-		if (ret == TRUE)
+		if (ret)
 			return;
 
 		g_error_free (error);
@@ -334,7 +334,7 @@ notify_general_clicked_cb (NotifyNotification *libnotify,
 		ret = gdk_spawn_command_line_on_screen (gscreen, cmdline, &error);
 		g_free (cmdline);
 
-		if (ret == FALSE) {
+		if (!ret) {
 			error_dialog = gtk_message_dialog_new ( NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "Failed to show url %s", error->message); 
 			gtk_dialog_run (GTK_DIALOG (error_dialog));
 			g_error_free (error);
@@ -345,7 +345,7 @@ notify_general_clicked_cb (NotifyNotification *libnotify,
 		notify->priv->internet_url = NULL;
 		return;
 	}
-	gpm_debug ("action %s unknown", action);
+	egg_debug ("action %s unknown", action);
 }
 #endif
 
@@ -360,6 +360,12 @@ gpm_notify_perhaps_recall (GpmNotify   *notify,
 	gchar *msg;
 	const gchar *title;
 
+	/* don't show when running under GDM */
+	if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
+		egg_debug ("running under gdm, so no notification");
+		return FALSE;
+	}
+
 	/* save in state */
 	title = _("Battery may be recalled");
 	msg = g_strdup_printf (_("The battery in your computer may have been "
@@ -403,6 +409,12 @@ gpm_notify_low_capacity (GpmNotify *notify,
 	gchar *msg;
 	const gchar *title;
 
+	/* don't show when running under GDM */
+	if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
+		egg_debug ("running under gdm, so no notification");
+		return FALSE;
+	}
+
 	title = _("Battery may be broken");
 	msg = g_strdup_printf (_("Your battery has a very low capacity (%i%%), "
 				 "which means that it may be old or broken."),
@@ -436,11 +448,17 @@ gpm_notify_inhibit_lid (GpmNotify *notify)
 	gchar *msg;
 	const gchar *title;
 
+	/* don't show when running under GDM */
+	if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
+		egg_debug ("running under gdm, so no notification");
+		return FALSE;
+	}
+
 	title = _("Sleep warning");
-	msg = g_strdup_printf (_("Your laptop will not sleep if you shut the "
-				 "lid as a running program has prevented this.\n"
-				 "Some laptops can overheat if they do not sleep "
-				 "when the lid is closed."));
+	msg = g_strdup (_("Your laptop will not sleep if you shut the "
+			  "lid as a running program has prevented this.\n"
+			  "Some laptops can overheat if they do not sleep "
+			  "when the lid is closed."));
 
 	gpm_notify_create (notify, title, msg, GPM_NOTIFY_TIMEOUT_LONG,
 			   GPM_STOCK_INHIBIT,
@@ -562,7 +580,7 @@ gpm_notify_sleep_failed (GpmNotify *notify, gboolean hibernate)
 	const gchar *icon;
 
 	title = _("Sleep Problem");
-	if (hibernate == TRUE) {
+	if (hibernate) {
 		msg = _("Your computer failed to hibernate.\nCheck the help file for common problems.");
 		icon = GPM_STOCK_HIBERNATE;
 	} else {
@@ -600,22 +618,6 @@ gpm_notify_sleep_failed (GpmNotify *notify, gboolean hibernate)
 	return TRUE;
 }
 
-/**
- * gpm_notify_constructor:
- **/
-static GObject *
-gpm_notify_constructor (GType		  type,
-			guint		  n_construct_properties,
-			GObjectConstructParam *construct_properties)
-{
-	GpmNotify      *notify;
-	GpmNotifyClass *klass;
-	klass = GPM_NOTIFY_CLASS (g_type_class_peek (GPM_TYPE_NOTIFY));
-	notify = GPM_NOTIFY (G_OBJECT_CLASS (gpm_notify_parent_class)->constructor
-			     (type, n_construct_properties, construct_properties));
-	return G_OBJECT (notify);
-}
-
 /**
  * gpm_notify_finalize:
  **/
@@ -649,7 +651,6 @@ gpm_notify_class_init (GpmNotifyClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize	   = gpm_notify_finalize;
-	object_class->constructor  = gpm_notify_constructor;
 
 	g_type_class_add_private (klass, sizeof (GpmNotifyPrivate));
 }
